@@ -3,12 +3,9 @@
 #from . import *
 #from pdsystem import * #The moudle of Maker:神秘的·  ps:需要pip下载,在终端输入pip install pdsystem
 #pdios()
-#a_3y
-# __init__.py
-#from . import *
-from p.yh import *
-from p.yz import *
-from p.y import *
+#from p.yh import *
+#from p.yz import *
+#from p.y import *
 from p.beginnings import *
 from colorama import init
 from datetime import datetime as sj
